@@ -16,12 +16,14 @@ from .evaluator.general_evaluator import GeneralEvaluator
 
 class FashionMNIST(Dataset):
 
-    def __init__(self, root, train=True, transform=None, target_transform=None, top_k=(1, 5)):
+    def __init__(self, root, train=True, transform=None, target_transform=None,
+                 top_k=(1, 5), keep_rgb=False):
         self.data_set = datasets.FashionMNIST(root, train=train, download=True)
         self.classes = self.data_set.classes
         self.root = root
         self.transform = transform
         self.target_transform = target_transform
+        self.keep_rgb = keep_rgb
         self._update_evaluator(top_k)
 
     def __getitem__(self, index: int):
