@@ -16,17 +16,18 @@ from .evaluator.general_evaluator import GeneralEvaluator
 
 class GeneralDataset(Dataset):
 
-    def __init__(self, root, transform=None, target_transform=None, top_k=(1, 5)):
+    def __init__(self, root, transform=None, target_transform=None, top_k=(1, 5), keep_rgb=False):
         self.data_set = datasets.ImageFolder(root)
         self.classes = self.data_set.classes
         self.root = root
         self.transform = transform
         self.target_transform = target_transform
+        self.keep_rgb = keep_rgb
         self._update_evaluator(top_k)
 
     def __getitem__(self, index: int):
         image, target = self.data_set.__getitem__(index)
-        image = default_converter(image, rgb=False)
+        image = default_converter(image, rgb=self.keep_rgb)
 
         if self.transform is not None:
             image = self.transform(image)
