@@ -16,7 +16,7 @@ from .evaluator.general_evaluator import GeneralEvaluator
 
 class ImageNet(Dataset):
 
-    def __init__(self, root, train=True, transform=None, target_transform=None, top_k=(1, 5)):
+    def __init__(self, root, train=True, transform=None, target_transform=None, top_k=(1, 5), keep_rgb=False):
         split = 'train' if train else 'val'
         # using torchvision ImageNet to get classes
         self.data_set = datasets.ImageNet(root, split=split)
@@ -26,12 +26,13 @@ class ImageNet(Dataset):
         self.root = root
         self.transform = transform
         self.target_transform = target_transform
+        self.keep_rgb = keep_rgb
         # create evaluator
         self._update_evaluator(top_k)
 
     def __getitem__(self, index: int):
         image, target = self.data_set.__getitem__(index)
-        image = default_converter(image, rgb=False)
+        image = default_converter(image, rgb=self.keep_rgb)
 
         if self.transform is not None:
             image = self.transform(image)
