@@ -51,7 +51,7 @@ class GeneralHead3D(nn.Module, ABC):
 @registry.HEAD.register('GeneralHead3D')
 def build_general_head_3d(cfg):
     feature_dims = cfg.MODEL.HEAD.FEATURE_DIMS
-    num_classes = cfg.MODEL.RECOGNIZER.PRETRAINED_NUM_CLASSES
+    num_classes = cfg.MODEL.HEAD.NUM_CLASSES
     dropout_rate = cfg.MODEL.HEAD.DROPOUT_RATE
 
     return GeneralHead3D(feature_dims=feature_dims,
